<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/**
 * Custom text for 'woocommerce_product_add_to_cart_text' filter for all product types/ cases.
 *
 * @param  $default, is the default add to cart text
 *
 * @global $product
 *
 * @return string String for add to cart text.
 */

add_filter( 'woocommerce_product_add_to_cart_text', 'bcfw_replace_shop_add_to_cart_text', 100 );

function bcfw_replace_shop_add_to_cart_text( $default ) {

	$options = get_option( 'button-customizer-general' );

	// security, return the default filter.
	if (  empty( $options ) || empty( $options['change_on_filters']['shop'] ) ) {
		return $default;
	}

	if ( $options['enable'] == 'off' || $options['change_on_filters']['shop'] != 'shop' ) {
		return $default;
	}

	return bcfw_get_button_texts( $options, $default );
}

/**
 * Changes the $default add to cart buttons on single products
 *
 * @param  $default
 *
 * @global $product
 *
 * @return string String for add to cart text.
 */
add_filter( 'woocommerce_product_single_add_to_cart_text', 'bcfw_replace_single_add_to_cart_text', 100 );

function bcfw_replace_single_add_to_cart_text( $default ) {

	$options = get_option( 'button-customizer-general' );

	// security, return the default filter.
	if (  empty( $options ) || empty( $options['change_on_filters']['single'] ) ) {
		  return $default;
	}

	if ( empty( $options ) ||  $options['enable'] == 'off' || $options['change_on_filters']['single'] != 'single' ) {
			return $default;
	}

	return bcfw_get_button_texts( $options, $default );

}

/**
 * Get new button text from options per product type.
 *
 * @return string
 */
function bcfw_get_button_texts( $options, $default ) {

	global $product;
	$product_type = $product->get_type();

	switch ( $product_type ) {
		// Grouped Products
		case 'external':
			$external = ( ! empty( $options['external_product'] ) ? $options['external_product'] : $default );
			return $external;
		break;

		// Grouped Products
		case 'grouped':
			$grouped = ( ! empty( $options['grouped_product'] ) ? $options['grouped_product'] : $default );
			return $grouped;
		break;

		// Simple Products
		case 'simple':
			$simple = ( ! empty( $options['simple_product'] ) ? $options['simple_product'] : $default );
			return $simple;
		break;

		// Variable Products
		case 'variable':
			$variable = ( ! empty( $options['variable_product'] ) ? $options['variable_product'] : $default );
			return $variable;
		break;

		// Bookable Products
		case 'booking':
			$booking = ( ! empty( $options['booking_product'] ) ? $options['booking_product'] : $default );
			return $booking;
		break;

		// Bookable Accomondation products
		case 'accommodation-booking':
			$accomondation = ( ! empty( $options['accomondation_product'] ) ? $options['accomondation_product'] : $default );
			return $accomondation;
		break;

		// Default fallback
		default:
			$fallback = ( ! empty( $options['fallback'] ) ? $options['fallback'] : $default );
			return $fallback;
	}  // end switch

}
